@@ -1,5 +1,5 @@
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.992';
+$Geo::Address::Formatter::VERSION = '1.993';
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 use strict;
@@ -32,10 +32,12 @@ sub new {
     my $conf_path = $params{conf_path} || die "no conf_path set";
 
     # optional params
-    $show_warnings  = 0 if (defined($params{no_warnings})  && $params{no_warnings});
-    $only_address   = 1 if (defined($params{only_address}) && $params{only_address});
-    $debug          = 1 if (defined($params{debug})        && $params{debug});
-    
+    if ( defined($params{no_warnings}) && ($params{no_warnings})){
+        $show_warnings  = 0;
+    }
+    $only_address  = (defined($params{only_address}) && $params{only_address}) // 0;
+    $debug         = (defined($params{debug})        && $params{debug})        // 0;
+
     $self->{final_components} = undef;
     bless($self, $class);
 
@@ -193,6 +195,12 @@ sub format_address {
     # 2b. should we abbreviate?
     my $abbrv = $rh_options->{abbreviate} // 0;
 
+    # 2c. was only_address set at the formatting level
+    my $oa = $only_address;
+    if (defined($rh_options->{only_address})){
+        $oa = $rh_options->{only_address};
+    }
+
     if ($debug){
         say STDERR "component_aliases";
         say STDERR Dumper $self->{component_aliases};
@@ -287,13 +295,14 @@ sub format_address {
     if ($debug){
         say STDERR "unknown_components:";
         say STDERR Dumper $ra_unknown;
-        say STDERR "only_address: $only_address";
+        say STDERR "object level only_address: $only_address";
+        say STDERR "formatting level only_address: $oa";
     }
 
-    if ($only_address){
+    if ($oa){
         if ($debug){
             say STDERR "ignoring unknown_components because only_address was specified";
-        }        
+        }
     }
     elsif (scalar(@$ra_unknown)){
         $rh_components->{attention} = join(', ', map { $rh_components->{$_} } @$ra_unknown);
@@ -885,7 +894,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.992
+version 1.993
 
 =head1 SYNOPSIS
 
@@ -932,11 +941,7 @@ completion of B<format_address>. Warns if called before they have been set
 Given a structures address (hashref) and options (hashref) returns a
 formatted address.
 
-Possible options you are:
-
-    'country', which should be an uppercase ISO 3166-1:alpha-2 code
-    e.g. 'GB' for Great Britain, 'DE' for Germany, etc.
-    If ommited we try to find the country in the address components.
+Possible options are:
 
     'abbreviate', if supplied common abbreviations are applied
     to the resulting output.
@@ -944,6 +949,12 @@ Possible options you are:
     'address_template', a mustache format template to be used instead of the template
     defined in the configuration
 
+    'country', which should be an uppercase ISO 3166-1:alpha-2 code
+    e.g. 'GB' for Great Britain, 'DE' for Germany, etc.
+    If ommited we try to find the country in the address components.
+
+    'only_address', same as I<only_address> global option but set at formatting level
+
 =head1 DESCRIPTION
 
 You have a structured postal address (hash) and need to convert it into a
